/*
 * Copyright 2010 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package com.google.gwt.sample.expenses.gwt.request;

import com.google.gwt.requestfactory.shared.Id;
import com.google.gwt.requestfactory.shared.LongString;
import com.google.gwt.requestfactory.shared.Version;
import com.google.gwt.valuestore.shared.PrimitiveProperty;
import com.google.gwt.valuestore.shared.Property;
import com.google.gwt.valuestore.shared.Values;
import com.google.gwt.valuestore.shared.ValuesChangedEvent;
import com.google.gwt.valuestore.shared.impl.PrimitivePropertyImpl;
import com.google.gwt.valuestore.shared.impl.PropertyImpl;

import java.util.Date;
import java.util.HashSet;
import java.util.Set;

/**
 * "API Generated" key for proxy {@link com.google.gwt.valuestore.shared.Values
 * Values} of {@link com.google.gwt.sample.expenses.server.domain.Report
 * domain.Employee}.
 * <p>
 * IRL this class will be generated by a JPA-savvy tool run before compilation.
 */
public class ReportKey implements ExpensesKey<ReportKey> {
  private static ReportKey instance;

  public static ReportKey get() {
    if (instance == null) {
      instance = new ReportKey();
    }
    return instance;
  }

  private final PrimitivePropertyImpl<ReportKey, String> id = new PrimitivePropertyImpl<ReportKey, String>(
      String.class, "id");

  private final PrimitivePropertyImpl<ReportKey, Integer> version = new PrimitivePropertyImpl<ReportKey, Integer>(
      Integer.class, "version");

  private final PrimitivePropertyImpl<ReportKey, Date> created = new PrimitivePropertyImpl<ReportKey, Date>(
      Date.class, "created");

  private final PrimitivePropertyImpl<ReportKey, String> purpose = new PrimitivePropertyImpl<ReportKey, String>(
      String.class, "purpose");

  private final Property<ReportKey, EmployeeKey> reporter = new PropertyImpl<ReportKey, EmployeeKey>(
      "reporter");

  private final Set<PropertyImpl<ReportKey, ?>> properties = new HashSet<PropertyImpl<ReportKey, ?>>();

  ReportKey() {
    properties.add(id);
    properties.add(version);
    properties.add(created);
    properties.add(purpose);
    for (PropertyImpl<ReportKey, ?> p : properties) {
      p.setKey(this);
    }
  }

  public <T> T accept(ExpensesKeyFilter<T> filter) {
    return filter.filter(this);
  }

  public void accept(ExpensesKeyVisitor visitor) {
    visitor.visit(this);
  }

  public Set<? extends Property<ReportKey, ?>> all() {
    return properties;
  }

  public ValuesChangedEvent<ReportKey, ?> createChangeEvent(
      Values<ReportKey> values) {
    return new ReportChanged(values);
  }

  public PrimitiveProperty<ReportKey, Date> getCreated() {
    return created;
  }

  @LongString
  @Id
  public PrimitiveProperty<ReportKey, String> getId() {
    return id;
  }

  public PrimitiveProperty<ReportKey, String> getPurpose() {
    return purpose;
  }

  public Property<ReportKey, EmployeeKey> getReporter() {
    return reporter;
  }

  @Version
  public PrimitiveProperty<ReportKey, Integer> getVersion() {
    return version;
  }
}
